@@ -1,17 +1,36 @@
 #
-# $Id: SimplePassword.pm 8 2006-10-19 23:59:11Z ryo $
+# $Id: SimplePassword.pm 13 2008-06-14 10:28:53Z ryo $
+
+package Data::SimplePassword::exception;
+
+use strict;
+use Carp;
+
+sub new { croak "couldn't find any suitable MT classes." }
 
 package Data::SimplePassword;
 
 use strict;
 use 5.00502;
 use vars qw($VERSION);
-use base qw(Class::Accessor::Fast);
+use base qw(Class::Accessor::Fast Class::Data::Inheritable);
+use CLASS;
 use Carp;
+use UNIVERSAL::require;
 use Crypt::Random ();
-use Math::Random::MT ();
 
-$VERSION = '0.02';
+$VERSION = '0.03';
+
+CLASS->mk_classdata( qw(class) );
+CLASS->mk_accessors( qw(seed_num) );
+
+{
+    Math::Random::MT->use
+        ? CLASS->class("Math::Random::MT")
+        : Math::Random::MT::Perl->use
+            ? CLASS->class("Math::Random::MT::Perl")
+            : CLASS->class("Data::SimplePassword::exception");
+}
 
 sub _default_chars { ( 0..9, 'a'..'z', 'A'..'Z' ) }
 
@@ -20,12 +39,10 @@ sub new {
     my $class = ref $param || $param;
     my %args = (
 	chars => undef,
-	seed_num => 1,    # now internal only, up to 624
+	seed_num => 1,    # now internal use only, up to 624
 	@_
     );
 
-    $class->mk_accessors( qw(seed_num) );
-
     return bless { %args }, $class;
 }
 
@@ -50,9 +67,9 @@ sub make_password {
     croak "length must be an integer."
 	unless $len =~ /^\d+$/o;
 
-    my @chars = ref $self->chars eq 'ARRAY' ? @{ $self->chars } : $self->_default_chars;
+    my @chars = defined $self->chars && ref $self->chars eq 'ARRAY' ? @{ $self->chars } : $self->_default_chars;
 
-    my $gen = Math::Random::MT->new( map { Crypt::Random::makerandom( Size => 32, Strength => 1 ) } 1 .. $self->seed_num );
+    my $gen = $self->class->new( map { Crypt::Random::makerandom( Size => 32, Strength => 1 ) } 1 .. $self->seed_num );
     my $password = join '', @chars[ map { int $gen->rand( scalar @chars ) } 1 .. $len ];
 
     return $password;
@@ -62,8 +79,6 @@ sub make_password {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Data::SimplePassword - Simple random password generator
@@ -85,6 +100,12 @@ YA very easy-to-use but a bit strong random password generator.
 
 =over 4
 
+=item B<new>
+
+ my $sp = Data::SimplePassword->new;
+
+Makes a Data::SimplePassword object.
+
 =item B<chars>
 
  $sp->chars( 0..9, 'a'..'z', 'A'..'Z' );    # default
@@ -92,7 +113,7 @@ YA very easy-to-use but a bit strong random password generator.
  $sp->chars( 0..9 );
  my @c = $sp->chars;    # returns the current values
 
-Sets an array of characters you want to use in your password string.
+Sets an array of characters you want to use as your password string.
 
 =item B<make_password>
 
@@ -105,14 +126,21 @@ Makes password string and just returns it. You can set the byte length as an int
 
 =head1 DEPENDENCY
 
-Class::Accessor, Crypt::Random, Math::Random::MT
+CLASS, Class::Accessor, Class::Data::Inheritable, Crypt::Random, Math::Random::MT (or Math::Random::MT::Perl),
+UNIVERSAL::require
 
 =head1 SEE ALSO
 
-Crypt::GeneratePassword, Crypt::RandPasswd, Data::RandomPass, String::MkPasswd
+Crypt::GeneratePassword, Crypt::RandPasswd, Data::RandomPass, String::MkPasswd, Data::Random::String
 
 =head1 AUTHOR
 
-Ryo Okamoto <ryo at aquahill dot net>
+Ryo Okamoto C<< <ryo at aquahill dot net> >>
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2006-2008 Ryo Okamoto, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
-=cut
